| Title: | Uniform Exact Functional Tests for Contingency Tables |
|---|---|
| Description: | Testing whether two discrete variables have a functional relationship under null distributions where the two variables are statistically independent with fixed marginal counts. The fast enumeration algorithm was based on (Nguyen et al. 2020) <doi:10.24963/ijcai.2020/372>. |
| Authors: | Yiyi Li [aut, cre] |
| Maintainer: | Yiyi Li <[email protected]> |
| License: | LGPL (>= 3) |
| Version: | 1.0.1 |
| Built: | 2026-05-15 05:45:46 UTC |
| Source: | https://github.com/cran/UniExactFunTest |
Perform the uniform exact functional test on a contingency table to determine if the column variable is a function of the row variable.
UEFT(input, correct, log.p)UEFT(input, correct, log.p)
input |
A matrix of nonnegative integers representing a contingency table. Column is the casual and row is the effect. |
correct |
Logical; if implement the continuity correction. The description is at details. The default is TRUE. |
log.p |
Logical; if TRUE, the p-value is given as log(p). The default is FALSE. The default is FALSE. |
The uniform idea was implementated using uniform marginal distribution of a square table as null hypothesis.
The exact p-value of the test.
The functions provide a direct entry into the C++ implementations of the exact functional test.
Yiyi Li, Joe Song
# Initial a table x = matrix(c(0,5,10,0,0,5), ncol=3) # With continuity correction UEFT(x) # Without continuity correction UEFT(x, FALSE)# Initial a table x = matrix(c(0,5,10,0,0,5), ncol=3) # With continuity correction UEFT(x) # Without continuity correction UEFT(x, FALSE)